# Generated by Django 5.0 on 2024-05-20 12:31

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="BatonTheme",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False, verbose_name="id")),
                ("name", models.CharField(max_length=255, verbose_name="name")),
                ("theme", models.TextField(verbose_name="theme")),
                ("active", models.BooleanField(default=False, verbose_name="active")),
            ],
            options={
                'verbose_name': 'admin theme',
                'verbose_name_plural': 'admin themes'
            }
        ),
    ]
