// scss-lint:disable IdSelector PlaceholderInExtend NestingDepth QualifyingElement SelectorDepth ImportantRule
.passwordchange,
.auth-user.change-form {

  #content-main {
    @extend .container-fluid;

    > form {
      @extend %admin-form;
    }

    .form-row {
      align-items: flex-start;
      display: flex;
      flex: 1;
      flex-direction: row;
      flex-wrap: wrap;
    }
  }
}
