// bootstrap
$primary: #208075;
$secondary: #2866ee;
$success: #2ecc71;
$warning: #f39c12;
$info: #3498db;
$btn-font-weight: 300; // Example: set font weight to semibold (default is 400)
// $btn-font-size: 0.9rem;

// fonts
$font-family-sans-serif: 'Inter Variable', sans-serif !default;

$h1-size: 1.8rem;
$h2-size: 1.5rem;
$h3-size: 1.3rem;
$modal-title-size: 1.6rem;
