.select2-container {
  max-width: 100% !important;
  min-width: 250px;

  .select2-selection {
    background: var(--bs-body-bg) !important;
    border: var(--bs-border-width) solid var(--bs-border-color) !important;
  }

  .select2-selection__arrow {
    margin-top: 0px;
  }
}

[data-bs-theme='dark'] {
  .select2-dropdown {
    background: var(--bs-body-bg);
    color: var(--bs-body-color);
  }
}

.select2-container--default .select2-selection--single .select2-selection__rendered {
  color: var(--bs-body-color) !important;
  margin-top: 2px;
}

.select2-container--admin-autocomplete .select2-search--dropdown .select2-search__field,
.select2-container--default .select2-search--dropdown .select2-search__field {
  border: var(--bs-border-width) solid var(--bs-border-color) !important;
  outline: 0;
}

.select2-container--default .select2-results__option--highlighted[aria-selected],
.select2-results__option select2-results__option--highlighted,
.select2-container--admin-autocomplete .select2-results__option--highlighted[aria-selected] {
  background: var(--bs-info) !important;
  color: var(--bs-black) !important;
}
