// scss-lint:disable PlaceholderInExtend IdSelector
.site-footer {
  @extend .p-3;
  background: var(--bs-baton-footer-bg);
  // border-top: 1px solid var(--bs-baton-footer-border-color);
  bottom: 0;
  color: var(--bs-baton-footer-color);
  font-size: 0.9rem;
  left: 0;
  margin-top: 20px;
  position: absolute;
  width: 100%;
  z-index: 1001;

  p {
    margin-bottom: 5px;
    margin-top: 5px;
  }

  a {
    color: var(--bs-baton-footer-link-color);

    &:hover {
      color: var(--bs-baton-footer-link-hover-color);
    }
  }

  .btn-light {
    background: var(--bs-baton-footer-support-bg);
    border: 1px solid var(--bs-baton-footer-support-bg);
    color: var(--bs-baton-footer-support-color);

    &:hover {
      color: var(--bs-baton-footer-support-hover-color);
    }
  }
}

.login #footer {
  display: none;
}
