# Generated by Django 5.1.3 on 2024-12-02 08:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("baton", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="batontheme",
            options={
                "verbose_name": "admin theme",
                "verbose_name_plural": "admin themes",
            },
        ),
        migrations.AlterField(
            model_name="batontheme",
            name="active",
            field=models.BooleanField(default=False, verbose_name="active"),
        ),
        migrations.AlterField(
            model_name="batontheme",
            name="id",
            field=models.AutoField(
                primary_key=True, serialize=False, verbose_name="id"
            ),
        ),
        migrations.AlterField(
            model_name="batontheme",
            name="name",
            field=models.CharField(max_length=255, verbose_name="name"),
        ),
        migrations.AlterField(
            model_name="batontheme",
            name="theme",
            field=models.TextField(verbose_name="theme"),
        ),
    ]
