class AIModels:
    BATON_GPT_3_5_TURBO = "gpt-3.5-turbo"
    BATON_GPT_4_TURBO = 'gpt-4-turbo'
    BATON_GPT_4O = 'gpt-4o'
    BATON_GPT_4O_MINI = 'gpt-4o-mini'
    BATON_DALL_E_3 = 'dall-e-3'

    text_models = [
        BATON_GPT_3_5_TURBO,
        BATON_GPT_4_TURBO,
        BATON_GPT_4O,
        BATON_GPT_4O_MINI,
    ]
    image_models = [
        BATON_DALL_E_3,
    ]
    vision_models = [
        BATON_GPT_4O_MINI,
    ]
