// scss-lint:disable IdSelector PlaceholderInExtend NestingDepth QualifyingElement SelectorDepth ImportantRule
.delete-confirmation-content {
  @extend .m-3;
  @extend .p-3;
  background: var(--bs-baton-delete-confirmation-bg);
  border: 1px solid var(--bs-baton-delete-confirmation-border-color);

  form {
    input[type='submit'] {
      @extend .btn;
      @extend.btn-danger;
    }

    .cancel-link {
      @extend .btn;
      @extend.btn-primary;
    }
  }
}
