// scss-lint:disable IdSelector PlaceholderInExtend NestingDepth

@include media-breakpoint-up(lg) {
  .menu-mobile {
    #content {
      flex: 0 0 100% !important;
      max-width: 100% !important;
      width: 100% !important;
    }
  }
}

#content {
  background: var(--bs-baton-content-bg);
  margin-right: 0 !important;
  padding-left: 0 !important;
  padding-right: 0 !important;
  padding-top: 0 !important;
  position: relative;

  @include media-breakpoint-down(md) {
    flex: 0 0 100% !important;
    max-width: 100% !important;
  }

  > h1 {
    @extend .mb-0;
    @extend .p-3;
    background: var(--bs-baton-content-title-bg);
    font-size: $h1-size;
    font-weight: 500;

    + h2,
    + .messagelist + h2 {
      @extend .mb-0;
      @extend .px-3;
      background: var(--bs-baton-content-title-bg);
      font-size: 1.2rem;
      padding-bottom: 1rem;
    }
  }

  .object-tools {
    @extend .ps-0;
    @extend .m-2;
    display: flex;
    gap: 0.5rem;
    row-gap: 0.5rem;
    list-style-type: none;
    flex-wrap: wrap;
    float: right;

    li {
      display: inline-block;
    }

    a {
      @extend .btn;
      @extend .btn-primary;
      display: flex;
      align-items: center;
      height: 100%;

      &::before {
        @extend %material;
      }
    }
  }
}

.messagelist {
  list-style-type: none;
  margin: 0 1rem;
  margin-top: 1rem;
  padding: 0;

  li::before {
    margin-right: 0.5rem;
  }

  .success {
    @extend .alert;
    @extend .alert-success;
    @extend .ps-3;

    &::before {
      @extend %material;
      content: 'check';
    }
  }

  .info {
    @extend .alert;
    @extend .alert-info;
    @extend .ps-3;

    &::before {
      @extend %material;
      content: 'info';
    }
  }

  .warning {
    @extend .alert;
    @extend .alert-warning;
    @extend .ps-3;

    &::before {
      @extend %material;
      content: 'warning';
    }
  }

  .error {
    @extend .alert;
    @extend .alert-danger;
    @extend .ps-3;

    &::before {
      @extend %material;
      content: 'error';
    }
  }
}

// modal
.modal-header {
  align-items: center !important;
}

.modal-dialog button.back {
  align-items: center;
  background: var(--bs-baton-modal-back-btn-bg);
  border: none;
  border-radius: 50%;
  color: var(--bs-baton-modal-back-btn-color);
  display: flex;
  height: 24px;
  justify-content: center;
  position: relative;
  top: -4px;
  width: 24px;

  &:focus {
    border: none;
    outline: none;
  }
}
